#
# spec file for package ffms2
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2016 Packman Team <packman@links2linux.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname lib%{name}
%define soname 5
Name:           ffms2
Version:        5.0+0
Release:        1.4
Summary:        Wrapper library around FFmpeg libraries
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://github.com/FFMS/ffms2
Source:         %{name}-%{version}.tar.xz
Source1:        baselibs.conf
Patch0:         ffms2-pkgconfig.patch
BuildRequires:  automake
BuildRequires:  c++_compiler
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libavcodec) >= 60.31.0
BuildRequires:  pkgconfig(libavformat) >= 60.16.0
BuildRequires:  pkgconfig(libavutil) >= 58.29.0
BuildRequires:  pkgconfig(libswresample) >= 4.12.0
BuildRequires:  pkgconfig(libswscale) >= 7.5.0
BuildRequires:  pkgconfig(zlib)

%description
FFmpegSource (usually known as FFMS or FFMS2) is a wrapper
library around FFmpeg, plus some additional components to deal with file
formats libavformat has (or used to have) problems with.

%package -n ffmsindex
Summary:        Wrapper library around libffmpeg
Group:          Productivity/Multimedia/Other

%description -n ffmsindex
FFmpegSource (usually known as FFMS or FFMS2) is a wrapper
library around FFmpeg, plus some additional components to deal with file
formats libavformat has (or used to have) problems with.

%package -n %{libname}-%{soname}
Summary:        Wrapper library around libffmpeg
Group:          System/Libraries

%description -n %{libname}-%{soname}
FFmpegSource (usually known as FFMS or FFMS2) is a wrapper
library around FFmpeg, plus some additional components to deal with file
formats libavformat has (or used to have) problems with.

%package -n %{libname}-devel
Summary:        Wrapper library around libffmpeg
Group:          Development/Libraries/C and C++
Requires:       %{libname}-%{soname} = %{version}

%description -n %{libname}-devel
FFmpegSource (usually known as FFMS or FFMS2) is a wrapper
library around FFmpeg, plus some additional components to deal with file
formats libavformat has (or used to have) problems with.

%prep
%setup -q
%autopatch -p1

%build
./autogen.sh
%configure --docdir=%{_docdir}/%{libname}-devel \
           --disable-static --enable-shared

%make_build

%install
%make_install V=1
rm %{buildroot}%{_libdir}/%{libname}.la

%post -n %{libname}-%{soname} -p /sbin/ldconfig
%postun -n %{libname}-%{soname} -p /sbin/ldconfig

%files -n ffmsindex
%{_bindir}/ffmsindex

%files -n %{libname}-%{soname}
%license COPYING
%{_libdir}/%{libname}.so.%{soname}*

%files -n %{libname}-devel
%{_libdir}/%{libname}.so
%{_includedir}/ffms*
%{_libdir}/pkgconfig/%{name}.pc
%{_docdir}/%{libname}-devel

%changelog
* Tue Jun  4 2024 Mia Herkt <mia@0x0.st>
- Update to version 5.0+0:
  * Fixed all issues with FFmpeg 6.1 which is now the minimum
    requirement
  * Fixed av1 decoding
  * Added HDR10+ and DolbyVision metadata
  * Fixed audio decoding that could otherwise get stuck in an
    infinite loop on certain files
  * Fixed framerate in Avisynth when using VFR=>CFR mode
  * Dropped VapourSynth API3 support
  * Indexer now has a configurable progress update interval
  * Alpha planes are now correctly marked as being full range
  * The full set of demuxer options can now be passed using the
    FFMS2 API
  * Now sets channel layout in Avisynth+
  * Removed the unfixable and always broken rffmode from Avisynth
    source
* Mon Dec 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.40+44:
  * Update to current git master commit ff61bca.
  * Fix build with ffmpeg-5.
- Bump soname to 5 following upstream changes.
- Replace pkgconfig(libavresample) with pkgconfig(libswresample)
  BuildRequires: Current versions of ffmpeg do not provide
  libavresample.
* Wed Oct  7 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.40
  * Avisynth+ linux support
  * Added LastEndTime track property to make it possible to take
    the last frame's duration into account
  * Removed several deprecated functions and enums from the API
  * No longer assumes sub 1 fps framerates are invalid
  * Added support for floating point format output in
    VapourSynth and Avisynth+
  * Fixed issue with dropped/repeated frames in vc1 with
    multiple b-frames after seeking
  * Fixed issue with dropped/repeated frames in h264 when the
    reorder buffer size is too small
  * Improved seeking in mpeg and mpegts streams
  * Added rgb(a)p and several additional formats as output to
    Avisynth+
  * Added VP9 support
  * Fixed incorrectly reporting the output as limited range when
    it's in fact unknown and likely to be full range
  * Added mastering display metadata output
  * VapourSynth source now defaults to not outputting alpha
  * Removed the now unused demuxer, dumpmask, audiofile and utf8
    arguments from the source filters
  * Removed ability to dump audio tracks
  * Fixed incorrect colorimetry metadata reported when
    converting the output to another colorspace
  * Sources now simply reference the index instead of copying
    large parts of it
  * Use new FFmpeg decoding API
  * Fixed several bugs in output format selection
  * FFMSIndex will now properly error out with invalid arguments
  * Add rotation metadata export
  * Add stereoscopic metadata export
  * Removed support for old FFmpeg versions
  * Removed libav support
  * Discontinuous Timestamp Support
  * Add FFMS_Deinit
  * Fix mid-stream parameter changes
  * Fix decoding H.264 PAFF files with one field per packet
  * Fix delay calculations for H.264 PAFF files
  * Fix frame rate calculation for fields with one field per
    packet
- Switch to stable source tarball and drop _service file
* Tue Dec 24 2019 9+suse@cirno.systems
- Refresh ffms2-pkgconfig.patch
- Update to version 2.23+202.ga9e8f73:
  * See changelog at https://github.com/FFMS/ffms2/commits/master
* Wed Jun 28 2017 jengelh@inai.de
- Rectify RPM group and trim filler words.
* Thu Feb 23 2017 mimi.vx@gmail.com
- update to 2.23.1
  * Updated FFmpeg APIs used
  * Added new API that can read/write indexes to a memory buffer
  * Added support for high bitdepth output in Avisynth+
  * vapoursource: Add nfMakeLinear flag to better performance in most cases
  * Remove bad colorspace matrix guessing for YUV
  * Tell libavformat to discard packets we don't want
  * Restore original FFCopyrightInfringement behavior
  * Make FFMS_Init threadsafe
  * Support latest libav* APIs
* Sun May  1 2016 aloisio@gmx.com
- Update to 2.22
  * Fix possible off by 1 frame until first seek issue introduced
    in 2.21 (Myrsloik)
  * avisynth: Make FFMS2 a shorter alias for FFmpegSource2 to save
    some typing (Myrsloik)
  * avisynth: Moved all source functions in ffms2.avsi into the
    actual plugin (Myrsloik)
  * avisynth: Use 2.6 RC API and add output support for all new
    colorspaces (Myrsloik)
  * vapoursource: Fix swapped RGB channels bug introduced in
    2.21 (Myrsloik)
  * swscale: Drop pointless and slow bitexact flag from resizer
    settings (kodabb)
  * Add support for files with gaps between the audio packets
    (Plorkyeran)
  2.21:
  * Add missing constants for log levels (Myrsloik)
  * Fix bad decoder flush that discards the palette of raw video
    (Myrsloik)
  * Remove the SWScale function from Avisynth since SWScale is
    useless (Myrsloik)
  * Fix common framerate correction (Myrsloik)
  * vapoursource: The framerate and frame durations are now
    normalized (Myrsloik)
  * vapoursource: Add support for outputting the alpha channel
    too (Myrsloik)
  * vapoursource: Fix resizer selection so bicubic isn't always
    used (Myrsloik)
  * vapoursource: Set chroma location and full colorspace
    information (Myrsloik)
  * Add support for indexing files with more than 32 tracks and
    the possibility to skip indexing of video tracks (Myrsloik)
  * The Avisynth plugin now sets all per frame variables in all
    modes to avoid ugly and slow FFInfo() errors (Myrsloik)
  * vapoursource: Fix crash on single frame files (Myrsloik)
  * Remove the Matroska and Haali demuxers (qyot27, Plorkyeran)
  * Fix adjustments for positive audio delay (tophf)
  * Don't try to index video tracks in unsupported formats
    (Daemon404)
  * Don't use scientific notation in timecode files (Daemon404)
  * Fix utf8 support in FFVideoSource (nixxquality)
  * Improve handling of files where only some packets have
    timestamps (Plorkyeran)
  * Fix memory leaks in the VapourSynth error handling (Plorkyeran)
  2.20:
  * Add support for Opus in MKV when ffmpeg/libav are built with
    libopus (qyot27)
  * vapoursource: Provide _AbsoluteTime metadata (Daemon404)
  * Fix a pile of small things found by Coverity (Daemon404)
  * Add support for HEVC in MKV (qyot27)
  * Fix infinite loop on garbage data at the beginning of AAC
    files (Plorkyeran)
  * Deal with the never-ending bitrot from FFmpeg/Libav API changes
    (Daemon404, Plorkyeran)
  * Make indexes not arch-specific and trivially smaller (Plorkyeran)
  * Fix bug where the first b-frame was replaced with the frame
    before it with open-gop h.264 (Plorkyeran)
  * Fix seeking issues with open-gop h.264 (Plorkyeran)
  * Fix corruption when seeking in interlaced h.264 (Plorkyeran)
  * Add support for multiple frames per audio packet as FFmpeg seems
    to have started doing that (Plorkyeran)
  * Fix seeking in Y4M files (Plorkyeran)
  * Fix dumping audio while indexing files
  * Add support for Matroska files with extremely large CodecPrivate
    sections
  * Speed up indexing Matroska files a bit
- Bumped soname to 4
- Switched to ffmpeg 3.0
* Wed Feb 17 2016 olaf@aepfle.de
- Remove unused Requires from pkgconfig file
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg BuildRequires
* Mon Apr 21 2014 i@margueirte.su
- update version 2.19.2
- drop patch: ffms2-2.17-ffmpeg_011.patch, upstreamed
- drop patch: ffms2-2.17-ffmpeg_10.patch, upstreamed
- drop patch: ffms2-2.17-ffmpeg_20.patch, upstream fixed
* Tue Jul 30 2013 i@margueirte.su
- Fix build with ffmpeg 2.0
* Fri Nov 16 2012 reddwarf@opensuse.org
- Fix build with ffmpeg 1.0
- Adapt the file list to be compatible with old RPMs
* Sun May 27 2012 reddwarf@opensuse.org
- Fix build with ffmpeg 0.11
* Fri Feb 10 2012 reddwarf@opensuse.org
- Update to 2.1.7
* Sat Oct 29 2011 reddwarf@opensuse.org
- First version
